//
//  NSObject+Signals.h
//  Signals
//
//  Created by Fredrik Olsson on 2006-09-26.
//  Copyright 2006 __MyCompanyName__. All rights reserved.
//

#import <Cocoa/Cocoa.h>


/*
 *	A category to NSObject to handle Qt-like Signals & Slots.
 *	A signal is identified with with an object of any class, just as keys
 *	in dictionaries.
 *	An arbitary number of targets can be connected to each signal.
 *	A target consist of a object and a selector implemented by the object.
 */
@interface NSObject (Signals)

//	Connect a signal to a target.
- (void)connectSignal:(id)signal withTarget:(id)target selector:(SEL)selector;

//	Connect a signal to a target, the target selector is determined by
//	using NSSelectorFromString() on the signal that must be a string.
- (void)connectSignal:(NSString *)signal withTarget:(id)target;

//	Remove a target for given signal, matching target and selector.
- (void)removeSignal:(id)signal withTarget:(id)target selector:(SEL)selector;

//	Remove targets for given signal, matching target and any selector.
- (void)removeSignal:(id)signal withTarget:(id)target;

//	Remove targets for given signal.
- (void)removeSignal:(id)signal;

//	Remove all signals.
- (void)removeAllSignals;

//	Emit a signal, calling all targets in undefined order.
- (void)emitSignal:(id)signal;

//	Emit a signal with argument, calling all targets in undefined order.
- (void)emitSignal:(id)signal withObject:(id)object;

@end